#
# spec file for package libHX
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           libHX
%define lname   libHX27
Summary:        Useful collection of routines for C and C++ programming
Version:        3.11
Release:        4.3.1
License:        LGPL v2+
Group:          System/Libraries
Source:         http://downloads.sf.net/libhx/libHX-%version.tar.xz
Source3:        http://downloads.sf.net/libhx/libHX-%version.tar.xz.asc
Source2:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++ pkg-config xz
%define debug_package_requires %lname = %version-%release
Url:            http://libhx.sf.net/

%description
libHX is a C library (with some C++ bindings available) that provides
data structures and functions commonly needed, such as maps, deques,
linked lists, string formatting and autoresizing, option and config
file parsing, type checking casts and more.

libHX aids in quickly writing up C and C++ data processing programs,
by consolidating tasks that often happen to be open-coded, such as
(simple) config file reading, option parsing, directory traversal,
and others, into a library. The focus is on reducing the amount of
time (and secondarily, the amount of code) a developer has to spend
for otherwise implementing such.


Authors:
--------
	Jan Engelhardt <jengelh [at] medozas de>

%package -n %lname


License:        LGPL v2+
Summary:        Useful collection of routines for C and C++ programming
Group:          System/Libraries

%description -n %lname
libHX is a C library (with some C++ bindings available) that provides
data structures and functions commonly needed, such as maps, deques,
linked lists, string formatting and autoresizing, option and config
file parsing, type checking casts and more.

libHX aids in quickly writing up C and C++ data processing programs,
by consolidating tasks that often happen to be open-coded, such as
(simple) config file reading, option parsing, directory traversal,
and others, into a library. The focus is on reducing the amount of
time (and secondarily, the amount of code) a developer has to spend
for otherwise implementing such.


Authors:
--------
	Jan Engelhardt <jengelh [at] medozas de>

%package devel
License:        LGPL v2+
Summary:        Useful collection of routines for C and C++ programming
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libHX is a C library (with some C++ bindings available) that provides
data structures and functions commonly needed, such as maps, deques,
linked lists, string formatting and autoresizing, option and config
file parsing, type checking casts and more.

libHX aids in quickly writing up C and C++ data processing programs,
by consolidating tasks that often happen to be open-coded, such as
(simple) config file reading, option parsing, directory traversal,
and others, into a library. The focus is on reducing the amount of
time (and secondarily, the amount of code) a developer has to spend
for otherwise implementing such.


Authors:
--------
	Jan Engelhardt <jengelh [at] medozas de>

%prep
%setup -q

%build
./autogen.sh
%configure --includedir=%_includedir/%name-%version
make %{?_smp_mflags}

%install
make install DESTDIR=%buildroot docdir=%_defaultdocdir/%name
mkdir -p "%buildroot/%_docdir";
install -pm0644 doc/* "%buildroot/%_defaultdocdir/%name"
rm -f %buildroot/%_defaultdocdir/%name/Makefile*
find "%buildroot" -type f -name "*.la" -delete;

%check
make check

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
/%_libdir/%{name}*.so.*

%files devel
%defattr(-,root,root)
%docdir %_docdir/%name
%_docdir/%name
%_includedir/%{name}*
/%_libdir/%{name}*.so
%_libdir/pkgconfig/*.pc

%changelog
* Wed Aug 10 2011 jengelh@medozas.de
- Remove pkgincludedir.diff and instead just use --includedir
  to %%configure
* Mon Jul 25 2011 jengelh@medozas.de
- Update to new upstream release 3.11
  * string: add a HXQUOTE_BASE64 to HX_strquote
  * debug: new LD_PRELOAD-able library that does additional checks
  to the runtime
- Provide libHX-devel-32bit
* Mon Jun  6 2011 jengelh@medozas.de
- Put the libHX directory into a versioned directory to detect
  unwanted omission of libHX_CFLAGS in dependent projects
* Wed Apr  6 2011 jengelh@medozas.de
- Update to new upstream release 3.10.1
  * defs: BUILD_BUG_ON_EXPR had erroneously returned 1
- Add BuildRequires: pkg-config as per rpmlint suggestion
* Tue Apr  5 2011 jengelh@medozas.de
- Update to new upstream release 3.10
  * format: do not split arguments in %%(lower) and %%(upper)
  * defs: add array type checking in ARRAY_SIZE
  * opt: use non-zero sentinel marker
  * defs: add BUILD_BUG_ON_EXPR
  * format: provide a %%(substr) function
  * io: add HX_readlink (zero-terminating mc-output readlink)
  * io: add HX_realpath (supports relative-path output)
* Mon Jan 17 2011 jengelh@medozas.de
- Update to new upstream release 3.9.1
  * Package missing header file
* Sat Jan 15 2011 jengelh@medozas.de
- Update to new upstream release 3.9
  * Add missing includes and guard to public include files
  * For filesystem/filehandle-related functions, io.h should now be
  included in userspace programs instead of misc.h
  * hxdirstamp: new development helper program for library users
  * io: new functions HXio_full{read,write}
* Wed Dec  1 2010 jengelh@medozas.de
- Update to new upstream release 3.8
  * HXdir_{open,read,close} now work with struct HXdir *
  instead of void *
  * xml_newnode prototype changed to accomodate subtext
- Run hxtools's spec-beautifier on specfile
* Wed Aug 25 2010 jengelh@medozas.de
- update to new upstream version 3.6
  * Fixes in 3.6:
  * bitmap: set/clear/test had no effect due to wrong type selection
  * bitmap: avoid left-shift larger than type on 64-bit
  * string: fixed buffer overflow in HX_split when too few fields were present
  in the input (CVE-2010-2947)
  * Fixes in 3.5:
  * format2: failure to skip escaped char in "%%(echo foo\ bar)" was corrected
  * proc: properly check for HXPROC_STDx--HXPROC_STDx_NULL overlap
  * strquote: do not cause allocation with invalid format numbers
  * Enhancements:
  * new format2 expandable functions like %%(exec) and %%(shell)
  * LDAP search filter and RDN quoting support
  * Old formatter was removed
* Wed Apr  7 2010 jengelh@medozas.de
- update to upstream version 3.4
  * explicit library initializer function
* Thu Jan 21 2010 jengelh@medozas.de
- update to upstream version 3.3
  * fixes to the quote processing of the format1 and shconfig parsers
  * introduces a new string formatter
* Wed Dec  9 2009 jengelh@medozas.de
- update descriptions in specfile
- do not pass --with-pkgconfigdir to configure;
  build already does it right
- update to upstream version 3.2
  * defs: add HXsizeof_member and HXtypeof_member
  * map: new map API, with hash-based maps and classic
    rbtree-based maps
  * arbtree: HXbtree was removed in favor of the new HXmap
  * clist: clist.h moved into list.h
  * format: HXformat_* now uses struct HXformat_map
  * rand: use faster modulo-based variant for numbers within
    RAND_MAX range
  * rand: use libc rand() almost exclusively, only use
    /dev/urandom for seed
  * time: add time delta functions
  * added HXbitmap_* functions
- add baselibs.conf as a Source, so that it is available on local
  builds too
* Mon Jul 27 2009 mc@novell.com
- Version 2.9
  - string: fixed number of fields and trailing NULL in HX_split4
  - string: add HX_basename_exact
  - HXproc now knows about HXPROC_NULL_*, which can be used to discard I/O
  - HXproc: expressly prohibit HXPROC_STD* for HXproc_run_sync
* Mon May 11 2009 mc@suse.de
- update to version 2.7
  - update ducumentation
  - arbtree: add "flat view" operation
  - misc: added HX_fls
  - misc: make HX_time_compare otime-capable
  - add wx_helper.hpp
* Wed Feb 18 2009 mc@suse.de
- update to version 2.5
  * a lot of new features and fixes
    see /usr/share/doc/packages/libHX/changelog.txt for details
  * move lib back to /usr/lib/
* Thu Jan 29 2009 crrodriguez@suse.de
- move .so symlinks to %%%%{_libdir}
- fix -devel package dependencies
* Wed Oct 22 2008 mrueckert@suse.de
- fix debug_packages_requires define
* Thu Sep 25 2008 mc@suse.de
- pointer was not automatically updated after hmc_trunc()
- make code resistant to memory allocation failure
* Fri Sep  5 2008 mc@suse.de
- update to version 1.23
  - code cleanup: misc.h has been split off libHX.h
  - add defs.h
- move libs to /lib[64] (required for pam_mount)
* Thu Aug 14 2008 mc@suse.de
- update to version 1.22
  * need to use lstat() on directory operations such as mkdir and rmdir
  * use RTLD_LAZY when opening dynamic libraries
  * add libxml_helper
* Fri Aug  1 2008 ro@suse.de
- fix requires for debuginfo package
* Mon Jun 23 2008 mc@suse.de
- package rename to libHX13, libHX-devel
- version 1.18
  - implement reverse iterating through HXlist
  - remove deprecated HXlist_init_head() and HXclist_init_head()
    [replaced by HXlist_init() and HXclist_init()]
  - added HX_ffs()
  - HXlist: added HXlist_for_each_safe, HXlist_for_each_entry_safe
  - HXclist: added HXclist_del
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Apr  7 2008 mc@suse.de
- version 1.15
  - HXformat: add %%(ifempty) and %%(ifnempty) tags
  - libHX.h: split into {arbtree,deque,option,string}.h (and libHX.h)
  - Add inline-doubly-linked-list data structures
* Wed Apr  2 2008 mc@suse.de
- version 1.10.2
  * bugfixes
* Mon Oct  8 2007 mc@suse.de
- version 1.10.1
  * Fix output of line-wrapped help text
  * fix tarball
- package pkgconfig file
* Thu Jul 12 2007 mc@suse.de
- initial release 1.10.0
